AE_IFMT   = 0o170000
AE_IFREG  = 0o100000
AE_IFLNK  = 0o120000
AE_IFSOCK = 0o140000
AE_IFCHR  = 0o020000
AE_IFBLK  = 0o060000
AE_IFDIR  = 0o040000
AE_IFIFO  = 0o010000

FILETYPES = {
    'IFREG': AE_IFREG,
    'IFLNK': AE_IFLNK,
    'IFSOCK': AE_IFSOCK,
    'IFCHR': AE_IFCHR,
    'IFBLK': AE_IFBLK,
    'IFDIR': AE_IFDIR,
    'IFIFO': AE_IFIFO,
}
